@@ -143,10 +143,24 @@ class Dataset:
         """
         self.tablegroup = tablegroup
         self.auto_constraints()
-        self.sources = Sources.from_file(self.bibpath)
+        self._sources = None
         self._objects = collections.defaultdict(collections.OrderedDict)
         self._objects_by_pk = collections.defaultdict(collections.OrderedDict)
 
+    @property
+    def sources(self):
+        # We load sources only the first time they are accessed, because for datasets like
+        # Glottolog - with 40MB zipped BibTeX - this may take ~90secs.
+        if self._sources is None:
+            self._sources = Sources.from_file(self.bibpath)
+        return self._sources
+
+    @sources.setter
+    def sources(self, obj):
+        if not isinstance(obj, Sources):
+            raise TypeError('Invalid type for Dataset.sources')
+        self._sources = obj
+
     #
     # Factory methods to create `Dataset` instances.
     #
@@ -850,11 +864,15 @@ class Dataset:
         """
         return self.tablegroup.to_file(fname or self.tablegroup._fname)
 
-    def write_sources(self):
+    def write_sources(self, zipped: bool = False) -> typing.Union[None, pathlib.Path]:
         """
         Write the sources BibTeX file to :meth:`~pycldf.dataset.Dataset.bibpath`
+
+        :return: `None`, if no BibTeX file was written (because no source items were added), \
+        `pathlib.Path` of the written BibTeX file otherwise. Note that this path does not need \
+        to exist, because the content may have been added to a zip archive.
         """
-        return self.sources.write(self.bibpath)
+        return self.sources.write(self.bibpath, zipped=zipped)
 
     def write(self,
               fname: typing.Optional[pathlib.Path] = None,
@@ -874,7 +892,8 @@ class Dataset:
         zipped = zipped or set()
         if self.sources and not self.properties.get('dc:source'):
             self.properties['dc:source'] = 'sources.bib'
-        self.write_sources()
+        self.write_sources(
+            zipped=self.properties.get('dc:source') in zipped or ('Source' in zipped))
         for table_type, items in table_items.items():
             table = self[table_type]
             table.common_props['dc:extent'] = table.write(items, _zipped=table_type in zipped)
