@@ -10,7 +10,7 @@ import pycldf
 
 __all__ = [
     'pkg_path', 'multislice', 'resolve_slices', 'DictTuple', 'metadata2markdown', 'qname2url',
-    'sanitize_url', 'iter_uritemplates', 'url_without_fragment']
+    'sanitize_url', 'update_url', 'iter_uritemplates', 'url_without_fragment']
 
 
 def url_without_fragment(url: typing.Union[str, urllib.parse.ParseResult]) -> str:
@@ -28,15 +28,21 @@ def iter_uritemplates(table):
                 yield obj, prop, tmpl
 
 
-def sanitize_url(url):
+def sanitize_url(url: str) -> str:
     """
     Removes auth credentials from a URL.
     """
-    u = urllib.parse.urlparse(url)
-    host = u.hostname
-    if u.port:
-        host += ':{}'.format(u.port)
-    return urllib.parse.urlunsplit((u.scheme, host, u.path, u.query, u.fragment)) or None
+    def fix(u):
+        host = u.hostname
+        if u.port:
+            host += ':{}'.format(u.port)
+        return (u.scheme, host, u.path, u.query, u.fragment)
+
+    return update_url(url, fix)
+
+
+def update_url(url: str, updater: typing.Callable[[urllib.parse.ParseResult], tuple]) -> str:
+    return urllib.parse.urlunsplit(updater(urllib.parse.urlparse(url))) or None
 
 
 def pkg_path(*comps):
